﻿#target photoshop

/*
This set of Photoshop scripts can be used for retouching 360 degree
panoramas.

The problem is that Photoshop isn't aware of the fact that the left
and right edge of the image wrap around. When doing local adjustments
(in particular contrast enhancement) near one of the edges pixels at
the other edge should be taken into account, otherwise a hard edge
will be visible when the panorama is wrapped around. These scripts
solve this problem.

The 'Extend Canvas' script copies a part from the left hand side of
the panorama and pastes it at the right hand side, and vice versa.
This ensures smooth adjustments near the original edges of the
panorama. Two vertical guides are placed at the original edges.

The 'Reduce Canvas' script does the opposite: it crops the panorama
back to the original dimensions.

HOW TO INSTALL:

The scripts come in two .jsx files. These need to be installed in
Photoshop's Presets/Scripts folder. This folder is scanned when
Photoshop starts and the scripts can be accessed from File - Scripts
in Photoshop. Quit Photoshop if it is running, then copy both .jsx
files to the following folders:


WINDOWS (64 BIT):

The 32 and 64 bit photoshop are installed in two separate folders.
Copy the .jsx files to both the following folders:

C:\Program Files (x86)\Adobe\Adobe Photoshop xxx\Presets\Scripts\
and
C:\Program Files\Adobe\Adobe Photoshop xxx (64 Bit)\Presets\Scripts\


WINDOWS (32 BIT):

C:\Program Files\Adobe\Adobe Photoshop xxx\Presets\Scripts\


MAC:

Copy the .jsx files to this folder: 
/Applications/Adobe Photoshop xxx/Presets/Scripts/


After restarting Photoshop the scripts can be accessed via 
File / Scripts / Panorama - Extend Canvas 
File / Scripts / Panorama - Reduce Canvas



(C) 2014 New House Internet Services BV

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

var originalUnit = app.preferences.rulerUnits;
app.preferences.rulerUnits = Units.PIXELS;

try
{
	var doc;
    try
    {
        doc=app.activeDocument;
     }
    catch(e)
    {
		throw new Error("Please open a panorama first");
    }
	if(doc.layers.length != 1)
	{
		throw new Error("Need a document with only 1 layer");
	}
	if('guides' in doc) // Document.guides was introduced after CS4
	{
		if(doc.guides.length != 2)
		{
			throw new Error("Need a document with 2 guides (have you run the extend-canvas script already?)");
		}
	}
	var backgroundlayer=doc.layers[0];

	var origwidth = doc.width;
	var origheight = doc.height;

	doc.resizeCanvas (origwidth/2, origheight, AnchorPosition.MIDDLECENTER);
    
	if('guides' in doc) // Document.guides was introduced after CS4
	{
		doc.guides.removeAll();
	}
}
catch(e)
{
	alert(e.message);
}
// Restore original ruler unit setting
app.preferences.rulerUnits = originalUnit;
